May 16, 2019.
Cambridge, MA.

## Configuration File

I think what I want to do is have the configuration file as it is, but remove the string IDs and turn them into class types. Then, I will only have the priorities and used_layers left. Then, when saytex is initialized, it is initialized with the values from the config file, but has local properties containing the used layers (as a set) and the priorities. This means that a user can easily create their own layer class and add it to the priorities and the used_layers set, as well as remove current layers from the set. Add two methods to facilitate this in the Saytex class. This should be relatively easy to fix.